@@ -49,7 +49,9 @@ def match_vlan_interface(device, job_def):
         if 'tags' not in device_dict['parameters']:
             return False
         for interface, tags in device_dict['parameters']['tags'].iteritems():
-            if any(set(tags).intersection(tag_list)) and interface not in interfaces:
+            # tags & job tags must equal job tags
+            # device therefore must support all job tags, not all job tags available on the device need to be specified
+            if set(tags) & set(tag_list) == set(tag_list) and interface not in interfaces:
                 logger.debug("Matched vlan %s to interface %s on %s", vlan_name, interface, device)
                 interfaces.append(interface)
                 # matched, do not check any further interfaces of this device for this vlan
@@ -58,18 +60,21 @@ def match_vlan_interface(device, job_def):
 
 
 def initiate_health_check_job(device):
+    logger = logging.getLogger('dispatcher-master')
+    logger.info("Initiating health check")
     if not device:
         # logic error
+        logger.error("No device")
         return None
     if device.status in [Device.RETIRED]:
         # logic error
+        logger.error("[%s] has been retired", device)
         return None
 
     existing_health_check_job = device.get_existing_health_check_job()
     if existing_health_check_job:
         return existing_health_check_job
 
-    logger = logging.getLogger('dispatcher-master')
     job_data = device.device_type.health_check_job
     user = User.objects.get(username='lava-health')
     if not job_data:
@@ -379,7 +384,8 @@ def _validate_queue():
     """
     logger = logging.getLogger('dispatcher-master')
     jobs = TestJob.objects.filter(status=TestJob.SUBMITTED)
-    jobs = jobs.filter(actual_device__isnull=False)
+    jobs = jobs.filter(actual_device__isnull=False) \
+               .select_related('actual_device', 'actual_device__current_job')
     for job in jobs:
         if not job.actual_device.current_job:
             device = Device.objects.get(hostname=job.actual_device.hostname)
@@ -513,9 +519,10 @@ def assign_jobs():
                 if 'protocols' in job_dict and 'lava-vland' in job_dict['protocols']:
                     if not match_vlan_interface(device, job_dict):
                         logger.debug("%s does not match vland tags", str(device.hostname))
-                        devices.remove(device)
+                        if device in devices:
+                            devices.remove(device)
                         continue
-            if not _validate_idle_device(job, device):
+            if not _validate_idle_device(job, device) and device in devices:
                 logger.debug("Removing %s from the list of available devices",
                              str(device.hostname))
                 devices.remove(device)
@@ -552,7 +559,6 @@ def assign_jobs():
     if postprocess and reserved_devices:
         logger.debug("All queued jobs checked, %d devices reserved and validated", len(reserved_devices))
 
-    # worker heartbeat must not occur within this loop
     logger.info("Assigned %d jobs on %s devices", len(assigned_jobs), len(reserved_devices))
 
 
@@ -777,7 +783,7 @@ def select_device(job, dispatchers):  # pylint: disable=too-many-return-statemen
             # pass (unused) output_dir just for validation as there is no zmq socket either.
             pipeline_job = parser.parse(
                 check_job.definition, parser_device,
-                check_job.id, None, output_dir=check_job.output_dir)
+                check_job.id, None, None, None, output_dir=check_job.output_dir)
         except (
                 AttributeError, JobError, NotImplementedError,
                 KeyError, TypeError, RuntimeError) as exc:
@@ -798,9 +804,10 @@ def select_device(job, dispatchers):  # pylint: disable=too-many-return-statemen
             # write the pipeline description to the job output directory.
             if not os.path.exists(check_job.output_dir):
                 os.makedirs(check_job.output_dir)
+            pipeline_dump = yaml.dump(pipeline)
             with open(os.path.join(check_job.output_dir, 'description.yaml'), 'w') as describe_yaml:
-                describe_yaml.write(yaml.dump(pipeline))
-            map_metadata(yaml.dump(pipeline), job)
+                describe_yaml.write(pipeline_dump)
+            map_metadata(pipeline_dump, job)
             # add the compatibility result from the master to the definition for comparison on the slave.
             if 'compatibility' in pipeline:
                 try:
