@@ -28,7 +28,6 @@ import socket
 import logging
 import urlparse
 import simplejson
-import models
 import subprocess
 import datetime
 import netifaces
@@ -38,7 +37,7 @@ from collections import OrderedDict
 from django.contrib.sites.models import Site
 from django.core.exceptions import ImproperlyConfigured
 from django.utils import timezone
-
+from lava_results_app.utils import check_request_auth
 from lava_server.settings.getsettings import Settings
 from lava_server.settings.config_file import ConfigFile
 from lava_scheduler_app.schema import SubmissionException
@@ -85,9 +84,8 @@ def rewrite_hostname(result_url):
     return result_url
 
 
-def split_multi_job(json_jobdata, target_group):
+def split_multi_job(json_jobdata, target_group):  # pylint: disable=too-many-branches,too-many-statements,too-many-locals
     node_json = {}
-    all_nodes = {}
     node_actions = {}
     node_lmp = {}
     shared_config = get_shared_device_config("/etc/lava-server/shared-device-config.yaml")
@@ -170,9 +168,8 @@ def split_multi_job(json_jobdata, target_group):
     return node_json
 
 
-def split_vm_job(json_jobdata, vm_group):
+def split_vm_job(json_jobdata, vm_group):  # pylint: disable=too-many-locals,too-many-statements,too-many-branches
     node_json = {}
-    all_nodes = {}
     node_actions = {}
     vms_list = []
 
@@ -292,7 +289,8 @@ def get_lshw_out():
     return simplejson.dumps(lshw_out)
 
 
-def get_ip_address():
+# pylint gets confused with netifaces
+def get_ip_address():  # pylint: disable=no-member
     """Returns the IP address of the default interface, if found.
     """
     ip = '0.0.0.0'
@@ -322,7 +320,7 @@ def format_sw_info_to_html(data_dict):
     return html_content
 
 
-def installed_packages(prefix=None, package_name=None):
+def installed_packages(prefix=None, package_name=None):  # pylint: disable=too-many-locals
     """Queries dpkg and filters packages that are related to PACKAGE_NAME.
 
     PREFIX is the installation prefix for the given instance ie.,
@@ -338,7 +336,7 @@ def installed_packages(prefix=None, package_name=None):
         proc = subprocess.Popen(package_cmd, shell=True,
                                 stdout=subprocess.PIPE,
                                 stderr=subprocess.PIPE)
-        package_out, package_err = proc.communicate()
+        package_out, _ = proc.communicate()
         pack_re = re.compile(r"ii\s+(?P<package>\S+)\s+(?P<version>\S+)\s+.*",
                              re.MULTILINE)
         for package in pack_re.findall(package_out):
@@ -350,7 +348,7 @@ def installed_packages(prefix=None, package_name=None):
         cmd = "grep exports %s" % python_path
         proc = subprocess.Popen(cmd, shell=True, stdout=subprocess.PIPE,
                                 stderr=subprocess.PIPE)
-        out, err = proc.communicate()
+        out, _ = proc.communicate()
 
         # The output of the command looks like the following, which is a
         # string, we process this string to populate the package dictionary.
@@ -404,7 +402,7 @@ def get_software_info():
 
     # Populate the git status of server code from exports directory.
     settings = Settings("lava-server")
-    instance_config_path = settings._get_pathname("instance")
+    instance_config_path = settings._get_pathname("instance")  # pylint: disable=protected-access
     instance_config = ConfigFile.load(instance_config_path)
     prefix = os.path.join(instance_config.LAVA_PREFIX,
                           instance_config.LAVA_INSTANCE)
@@ -426,16 +424,7 @@ def get_heartbeat_timeout():
 
     If there is no value found, we return a default timeout value 300.
     """
-    settings = Settings("lava-server")
-    worker_config_path = settings._get_pathname("worker")
-    try:
-        worker_config = ConfigFile.load(worker_config_path)
-        if worker_config and worker_config.HEARTBEAT_TIMEOUT != '':
-            return int(worker_config.HEARTBEAT_TIMEOUT)
-        else:
-            return 300
-    except (IOError, AttributeError):
-        return 300
+    return 300
 
 
 # Private variable to record scheduler tick, which shouldn't be accessed from
@@ -457,7 +446,7 @@ def last_scheduler_tick():
     return __last_scheduler_tick
 
 
-def process_repeat_parameter(json_jobdata):
+def process_repeat_parameter(json_jobdata):  # pylint: disable=too-many-branches
     new_json = {}
     new_actions = []
     allowed_actions = ["delpoy_linaro_image", "deploy_image",
@@ -521,7 +510,7 @@ def devicedictionary_to_jinja2(data_dict, extends):
         (including file name extension / suffix) which jinja2 will later
         assume to be in the jinja2 device_types folder
     """
-    if type(data_dict) is not dict:
+    if not isinstance(data_dict, dict):
         return None
     pp = pprint.PrettyPrinter(indent=0, width=80)  # simulate human readable input
     data = u'{%% extends \'%s\' %%}\n' % extends
@@ -537,7 +526,7 @@ def jinja2_to_devicedictionary(data_dict):
     Do some string mangling to convert the template to a key value store
     The reverse of lava_scheduler_app.utils.devicedictionary_to_jinja2
     """
-    if type(data_dict) is not str:
+    if not isinstance(data_dict, str):
         return None
     data = {}
     data_dict = data_dict.replace('\n', '')
@@ -684,8 +673,8 @@ def map_context_overrides(base_template, devicetype_template, system=True):  # p
         devicetype_data = content.read()
     base_keys = []
     devicetype_keys = []
-    base_pattern = '{%\s+set\s+(?P<key>\w+)'
-    devicetype_pattern = '{{\s+(?P<key>\w+)'
+    base_pattern = r'{%\s+set\s+(?P<key>\w+)'
+    devicetype_pattern = r'{{\s+(?P<key>\w+)'
     for line in base_data.split('\n'):
         match = re.match(base_pattern, line)
         if match:
@@ -718,7 +707,7 @@ def allowed_overrides(device_dict, system=True):
         return None
     with open(devicetype_file, 'r') as content:
         devicetype_data = content.read()
-    extends_pattern = "{%\s+extends\s+'(?P<key>\S+)'"
+    extends_pattern = r"{%\s+extends\s+'(?P<key>\S+)'"
     base_template = None
     for line in devicetype_data.split('\n'):
         match = re.search(extends_pattern, line)
@@ -742,7 +731,7 @@ def _split_multinode_vland(submission, jobs):
     return jobs
 
 
-def split_multinode_yaml(submission, target_group):  # pylint: disable=too-many-branches,too-many-locals
+def split_multinode_yaml(submission, target_group):  # pylint: disable=too-many-branches,too-many-locals,too-many-statements
     """
     Handles the lava-multinode protocol requirements.
     Uses the multinode protocol requirements to generate as many YAML
@@ -767,6 +756,7 @@ def split_multinode_yaml(submission, target_group):  # pylint: disable=too-many-
         'timeouts',
         'priority',
         'visibility',
+        'notify',
     ]
     skip = ['role', 'roles']
     scheduling = ['device_type', 'connection', 'host_role']  # top level values to be preserved
@@ -888,3 +878,10 @@ def mkdir(path):
             pass
         else:
             raise
+
+
+def check_user_auth(user, job, request=None):
+    if request:
+        check_request_auth(request, job)
+        return True
+    return job.can_view(user)
