@@ -17,11 +17,12 @@
 # along with LAVA Server.  If not, see <http://www.gnu.org/licenses/>.
 
 import sys
+import django
 from django.conf import settings
 from django.contrib.auth.decorators import login_required
-from django.core.urlresolvers import reverse
-from django.http import HttpResponse, HttpResponseServerError, HttpResponseForbidden
-from django.template import Context, loader, RequestContext
+from django.http import HttpResponseServerError, HttpResponseForbidden
+from django.shortcuts import render_to_response, render
+from django.template import loader, RequestContext
 from django.utils.translation import ugettext_lazy as _
 from django.views.decorators.csrf import requires_csrf_token
 
@@ -29,56 +30,50 @@ from lava_server.bread_crumbs import (
     BreadCrumb,
     BreadCrumbTrail,
 )
-from lava_server.extension import loader as extension_loader
 
 
 @BreadCrumb(_("LAVA"))
 def index(request):
-    # Start with a list of extensions
-    data = {
-        'extension_list': extension_loader.extensions,
-        'bread_crumb_trail': BreadCrumbTrail.leading_to(index),
-    }
-    # Append each extension context data
-    for extension in extension_loader.extensions:
-        data.update(extension.get_front_page_context())
     # Load and render the template
-    context = RequestContext(request, data)
-    template = loader.get_template('index.html')
-    return HttpResponse(template.render(context))
+    return render(request, 'index.html', {})
 
 
 @BreadCrumb(_("About you ({you})"),
             parent=index)
 @login_required
-def me(request):
+def me(request):  # pylint: disable=invalid-name
     data = {
         'bread_crumb_trail': BreadCrumbTrail.leading_to(
             me, you=request.user.get_full_name() or request.user.username),
     }
-    context = RequestContext(request, data)
-    template = loader.get_template('me.html')
-    return HttpResponse(template.render(context))
+    return render(request, 'me.html', data)
 
 
 @requires_csrf_token
 def server_error(request, template_name='500.html'):
-    t = loader.get_template(template_name)
-    exc_type, value, trace = sys.exc_info()
-    return HttpResponseServerError(
-        t.render(
-            Context(
-                {
-                    'STATIC_URL': settings.STATIC_URL,
-                    'user': request.user,
-                    'request': request,
-                    'exception_type': exc_type,
-                    'exception_value': value
-                })))
+    exc_type, value, _ = sys.exc_info()
+    context_dict = {
+        'STATIC_URL': settings.STATIC_URL,
+        'user': request.user,
+        'request': request,
+        'exception_type': exc_type,
+        'exception_value': value
+    }
+    if django.VERSION > (1, 8):
+        template = loader.get_template(template_name)
+        return HttpResponseServerError(template.render(context_dict, request))
+    else:
+        return render_to_response(
+            template_name, context_dict, RequestContext(request)
+        )
 
 
 @requires_csrf_token
 def permission_error(request, template_name='403.html'):
-    t = loader.get_template(template_name)
-    context = RequestContext(request)
-    return HttpResponseForbidden(t.render(context))
+    if django.VERSION > (1, 8):
+        template = loader.get_template(template_name)
+        return HttpResponseForbidden(template.render({}, request))
+    else:
+        return render_to_response(
+            template_name, {}, RequestContext(request)
+        )
